@@ -1,7 +1,7 @@
 package App::GraphicsColorNamesUtils;
 
 our $DATE = '2018-09-26'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -57,6 +57,48 @@ sub list_color_names {
     [200, "OK", \@rows, $resmeta];
 }
 
+$SPEC{show_color_swatch} = {
+    v => 1.1,
+    summary => 'List all color names from a Graphics::ColorNames scheme as a color swatch',
+    args => {
+        scheme => {
+            schema => 'perl::modname*',
+            req => 1,
+            pos => 0,
+        },
+        width => {
+            schema => 'posint*',
+            default => 80,
+            cmdline_aliases => {w=>{}},
+        },
+    },
+};
+sub show_color_swatch {
+    require Color::ANSI::Util;
+    require Color::RGB::Util;
+    require String::Pad;
+
+    my %args = @_;
+    my $width = $args{width} // 80;
+
+    my $res = list_color_names(scheme => $args{scheme}, detail=>1);
+    return $res unless $res->[0] == 200;
+
+    my $reset = Color::ANSI::Util::ansi_reset();
+    for my $row (@{ $res->[2] }) {
+        my $empty_bar = " " x $width;
+        my $text_bar  = String::Pad::pad("$row->{name} ($row->{rgb})", $width, "center", " ", 1);
+        my $bar = join(
+            "",
+            Color::ANSI::Util::ansibg($row->{rgb}), $empty_bar, $reset, "\n",
+            Color::ANSI::Util::ansibg($row->{rgb}), Color::ANSI::Util::ansifg(Color::RGB::Util::rgb_is_dark($row->{rgb}) ? "ffffff" : "000000"), $text_bar, $reset, "\n",
+            Color::ANSI::Util::ansibg($row->{rgb}), $empty_bar, $reset, "\n",
+            $empty_bar, "\n",
+        );
+        print $bar;
+    }
+    [200];
+}
 
 1;
 # ABSTRACT: Utilities related to Graphics::ColorNames
@@ -73,7 +115,7 @@ App::GraphicsColorNamesUtils - Utilities related to Graphics::ColorNames
 
 =head1 VERSION
 
-This document describes version 0.001 of App::GraphicsColorNamesUtils (from Perl distribution App-GraphicsColorNamesUtils), released on 2018-09-26.
+This document describes version 0.002 of App::GraphicsColorNamesUtils (from Perl distribution App-GraphicsColorNamesUtils), released on 2018-09-26.
 
 =head1 DESCRIPTION
 
@@ -85,6 +127,8 @@ This distributions provides the following command-line utilities:
 
 =item * L<list-color-schemes>
 
+=item * L<show-color-swatch>
+
 =back
 
 =head1 FUNCTIONS
@@ -145,6 +189,38 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 show_color_swatch
+
+Usage:
+
+ show_color_swatch(%args) -> [status, msg, result, meta]
+
+List all color names from a Graphics::ColorNames scheme as a color swatch.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<scheme>* => I<perl::modname>
+
+=item * B<width> => I<posint> (default: 80)
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-GraphicsColorNamesUtils>.
